@@ -61,7 +61,7 @@ This application implements the following features:
 """
 
 # This is injected automatically at release time
-__exact_version__ = 'v3.12'
+__exact_version__ = 'v3.19'
 
 import logging
 
@@ -78,11 +78,22 @@ logger = logging.getLogger(__name__)
 def favicon_view(request):
     "Serve /favicon.ico as an alias to /static/favicon.png"
 
-    import os
+    from os.path import dirname, join
     from pyramid.response import FileResponse
 
-    here = os.path.dirname(__file__)
-    icon = os.path.join(here, 'static', 'favicon.png')
+    here = dirname(__file__)
+    icon = join(here, 'static', 'favicon.png')
+    return FileResponse(icon, request=request)
+
+
+def robots_view(request):
+    "Serve /robots.txt as an alias to /static/robots.txt"
+
+    from os.path import dirname, join
+    from pyramid.response import FileResponse
+
+    here = dirname(__file__)
+    icon = join(here, 'static', 'robots.txt')
     return FileResponse(icon, request=request)
 
 
@@ -139,6 +150,9 @@ def main(global_config, **settings):
     config.add_route('favicon', '/favicon.ico')
     config.add_view(favicon_view, route_name='favicon')
 
+    config.add_route('robots', '/robots.txt')
+    config.add_view(robots_view, route_name='robots')
+
     # auth
 
     config.add_route('login', '/auth/login')
