@@ -345,7 +345,10 @@ class Deserializer(object):
                         logger.info('Updated %r: %s', player, changes_summary(changes))
 
         if merged:
-            player.mergePlayers(merged)
+            try:
+                player.mergePlayers(merged)
+            except OperationAborted as e:
+                logger.warn('Could not merge %r with %r: %s', player, merged, e)
 
         self.players.append(player)
 
