@@ -553,7 +553,8 @@ def interpolate_unrated(cache, ranking, glicko2, phantom_p, lower_rate, higher_r
     sumx = sumy = sumxy = sumx2 = phantoms = 0
 
     for x, competitor in enumerate(ranking, 1):
-        if phantom_p(competitor):
+        # Do not consider retired players when their only match was against the phantom
+        if phantom_p(competitor) or competitor.idplayer1 not in cache:
             phantoms += 1
             continue
 
