@@ -173,6 +173,7 @@ class Tourney(GloballyUnique, Base):
 
     finals = Column(
         smallint_t,
+        default=0,
         info=dict(label=N_('Finals'),
                   hint=N_('The number of finals that will be played: 0 means no finals,'
                           ' 1 means one final for the 1st and 2nd place, 2 also for the'
@@ -267,7 +268,13 @@ class Tourney(GloballyUnique, Base):
             else:
                 key = None
         else:
-            key = attrgetter('prize', 'points', 'bucholz', 'netscore', 'totscore')
+            if self.prized:
+                key = attrgetter('prize', 'points', 'bucholz', 'netscore', 'totscore')
+            else:
+                if self.idrating is not None:
+                    key = attrgetter('points', 'bucholz', 'netscore', 'totscore', 'rate')
+                else:
+                    key = attrgetter('points', 'bucholz', 'netscore', 'totscore')
 
         if key is None:
             ranking = competitors
@@ -460,57 +467,66 @@ class Tourney(GloballyUnique, Base):
             l -= 2
             b += 1
 
-    def _serialVisitor(self, a, list, skip):
-        """Visit the `list` in order.
+    def _serialVisitor(self, pivot, competitors, skip):
+        """Visit the `competitors` in order.
 
-        This is a generator, used by the combination maker in the simplest case:
-        it yields the position in the list, maintaining the order, of the items
-        that haven't played against competitor `a`. `skip` is a set containing
-        the previous matches (it contains both `(a,b)` and `(b,a)`). Given that
-        the list of competitors is sorted by their rank, this effectively tries
-        to combine players with the same strength.
+        :param pivot: a :py:class:`.Competitor>` instance
+        :param competitors: a list of possible opponents
+        :param done: the set of already played pairings
+
+        This is a generator, used by the combination maker in the simplest case: it yields the
+        position in the list, maintaining the order, of the items that haven't played against
+        competitor `pivot`. `skip` is a set containing the previous matches (it contains both
+        `(a,b)` and `(b,a)`).
+
+        Given that the list of competitors is sorted by their rank, this effectively tries to
+        combine players with the same strength.
         """
 
-        return (i for i in range(len(list))
-                if list[i] is not a and (a, list[i]) not in skip)
+        for i, c in enumerate(competitors):
+            if c is not pivot and (pivot, c) not in skip:
+                yield i
 
-    def _dazedVisitor(self, a, list, skip):
-        """Visit the `list`, giving precedence to the competitors with the same rank.
+    def _dazedVisitor(self, pivot, competitors, skip):
+        """Visit the `competitors`, giving precedence to the competitors with the same points.
 
-        Like `_serialVisitor()` this yields the position in the list
-        of the competitors that didn't meet `a`. It starts looking at
-        the competitors with the same points, and then goes on with
-        the others: this is to delay as much as possible the match
-        between the strongest competitors.
+        :param pivot: a :py:class:`.Competitor>` instance
+        :param competitors: a list of possible opponents
+        :param done: the set of already played pairings
+
+        Like `_serialVisitor()` this yields the positions of the competitors that didn't meet
+        `pivot`. It starts looking at the competitors with the same points, and then goes on
+        with the others: this is to postpone as much as possible the match between the
+        strongest competitors.
         """
 
-        # Competitor `a` is always the first in the list: first count
+        from itertools import chain
+
+        # Competitor `pivot` is always the first in the competitors: first count
         # how many have the same points, then if possible iterate over
         # the second half of them, then over the first half, and finally
         # over the remaining items.
 
         same_points = 0
-        for i in list:
-            # The list may contain the phantom, ie a None
-            if i is not None and i.points == a.points:
+        for c in competitors:
+            # The competitors may contain the phantom, ie pivot None
+            if c is not None and c.points == pivot.points:
                 same_points += 1
             else:
                 break
+
         if same_points > 3:
             middle = same_points // 2
-            for i in range(middle, same_points):
-                if list[i] is not a and (a, list[i]) not in skip:
-                    yield i
-            for i in range(0, middle):
-                if list[i] is not a and (a, list[i]) not in skip:
-                    yield i
-            for i in range(same_points, len(list)):
-                if list[i] is not a and (a, list[i]) not in skip:
-                    yield i
+            positions = chain(range(middle, same_points),
+                              range(0, middle),
+                              range(same_points, len(competitors)))
         else:
-            for i in range(len(list)):
-                if list[i] is not a and (a, list[i]) not in skip:
-                    yield i
+            positions = range(len(competitors))
+
+        for i in positions:
+            c = competitors[i]
+            if c is not pivot and (pivot, c) not in skip:
+                yield i
 
     def _combine(self, competitors, done, _level=0):
         """Build the next round, based on current ranking.
@@ -644,18 +660,27 @@ class Tourney(GloballyUnique, Base):
 
         newturn = last+1
         activecomps = [c for c in ranking if not c.retired]
+
         # Append the phantom if the number is odd
         if len(activecomps) % 2:
             activecomps.append(None)
 
         combination = self._combine(activecomps, done)
+        phantommatch = None
         if combination:
             matches = []
             for c1, c2 in combination:
-                m = Match(turn=newturn,
-                          competitor1=c1, competitor2=c2,
-                          score1=self.phantomscore if c2 is None else 0, score2=0)
-                matches.append(m)
+                # Put match against phantom last
+                if c2 is None:
+                    phantommatch = Match(turn=newturn,
+                                         competitor1=c1, competitor2=c2,
+                                         score1=self.phantomscore, score2=0)
+                else:
+                    m = Match(turn=newturn,
+                              competitor1=c1, competitor2=c2,
+                              score1=0, score2=0)
+                    matches.append(m)
+
                 # Take care of newly registered competitors
                 if c1 not in comp_boards:
                     comp_boards[c1] = set()
@@ -663,6 +688,11 @@ class Tourney(GloballyUnique, Base):
                     comp_boards[c2] = set()
 
             self._assignBoards(matches, comp_boards)
+
+            if phantommatch:
+                phantommatch.board = len(matches)+1
+                matches.append(phantommatch)
+
             self.matches.extend(matches)
         else:
             raise OperationAborted(
@@ -821,8 +851,10 @@ class Tourney(GloballyUnique, Base):
             championship = self.championship
         else:
             s = object_session(self)
-            championship = s.query(Championship).filter_by(idclub=self.championship.idclub,
-                                                           closed=False).first()
+            championship = s.query(Championship).filter_by(
+                idclub=self.championship.idclub,
+                playersperteam=self.championship.playersperteam,
+                closed=False).first()
             if championship is None:
                 raise OperationAborted(
                     _('Cannot replicate tourney, no open championships!'))
