@@ -407,12 +407,12 @@ class TourneyPrintout(BasicPrintout):
             try:
                 entity = session.query(Tourney).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad tourney id: $id',
-                                           mapping=dict(id=repr(id)))))
+                raise OperationAborted(t(_('No tourney with guid $id',
+                                           mapping=dict(id=id))))
         else:
             entity = session.query(Tourney).get(idtourney)
             if entity is None:
-                raise OperationAborted(t(_('Bad tourney id: $id',
+                raise OperationAborted(t(_('No tourney with id $id',
                                            mapping=dict(id=str(idtourney)))))
 
         return [entity]
@@ -659,7 +659,7 @@ class Ranking(TourneyPrintout):
         else:
             caption = gettext('Player')
 
-        if self.tourney.prized:
+        if self.tourney.prized and self.turn is None:
             if self.tourney.championship.prizes == 'asis':
                 npointcols = 3
                 rows = [('#',
@@ -1129,12 +1129,26 @@ class ScoreCards(TourneyPrintout):
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
         if request.matchdict['id'] != 'blank':
-            return super().getArgumentsFromRequest(session, request)
+            t = translator(request)
+            args = super().getArgumentsFromRequest(session, request)
+            kw = request.params
+            if 'starttime' in kw:
+                try:
+                    starttime = float(kw['starttime'])
+                    if starttime > 9999999999:
+                        starttime = starttime / 1000
+                    args.append(datetime.fromtimestamp(starttime))
+                except ValueError:
+                    raise OperationAborted(
+                        t(_('Invalid starttime: $starttime',
+                            mapping=dict(starttime=repr(kw['starttime'])))))
+            return args
         else:
             return [None]
 
-    def __init__(self, output, tourney, columns=2):
+    def __init__(self, output, tourney, starttime=None, columns=2):
         super(ScoreCards, self).__init__(output, tourney, columns)
+        self.starttime = starttime
 
     @property
     def cache_max_age(self):
@@ -1252,9 +1266,12 @@ class ScoreCards(TourneyPrintout):
                                   ])
 
         if self.tourney is not None:
-            now = datetime.now()
-            start = now + timedelta(minutes=9, seconds=45)
-            start += timedelta(minutes=5-start.minute%5)
+            if self.starttime:
+                start = self.starttime
+            else:
+                now = datetime.now()
+                start = now + timedelta(minutes=9, seconds=45)
+                start += timedelta(minutes=5-start.minute%5)
             end = start + timedelta(minutes=self.tourney.duration)
             # TRANSLATORS: this is strftime() format, see
             # http://docs.python.org/3/library/time.html#time.strftime
@@ -1326,12 +1343,12 @@ class Badges(object):
             try:
                 entity = session.query(Tourney).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad tourney id: $id',
-                                           mapping=dict(id=repr(id)))))
+                raise OperationAborted(t(_('No tourney with guid $id',
+                                           mapping=dict(id=id))))
         else:
             entity = session.query(Tourney).get(idtourney)
             if entity is None:
-                raise OperationAborted(t(_('Bad tourney id: $id',
+                raise OperationAborted(t(_('No tourney with id $id',
                                            mapping=dict(id=str(idtourney)))))
 
         return [entity]
@@ -1601,12 +1618,12 @@ class ChampionshipRanking(BasicPrintout):
             try:
                 entity = session.query(Championship).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad championship id: $id',
-                                           mapping=dict(id=repr(id)))))
+                raise OperationAborted(t(_('No championship with guid $id',
+                                           mapping=dict(id=id))))
         else:
             entity = session.query(Championship).get(idchampionship)
             if entity is None:
-                raise OperationAborted(t(_('Bad championship id: $id',
+                raise OperationAborted(t(_('No championship with id $id',
                                            mapping=dict(id=str(idchampionship)))))
 
         return [entity]
@@ -1822,12 +1839,12 @@ class RatingRanking(BasicPrintout):
             try:
                 entity = session.query(Rating).filter_by(guid=id).one()
             except NoResultFound:
-                raise OperationAborted(t(_('Bad rating id: $id',
-                                           mapping=dict(id=repr(id)))))
+                raise OperationAborted(t(_('No rating with guid $id',
+                                           mapping=dict(id=id))))
         else:
             entity = session.query(Rating).get(idrating)
             if entity is None:
-                raise OperationAborted(t(_('Bad rating id: $id',
+                raise OperationAborted(t(_('No rating with id $id',
                                            mapping=dict(id=str(idrating)))))
 
         return [entity, getattr(request, '_LOCALE_', 'en')]
