@@ -367,20 +367,20 @@ def load_historical_rating(args):
             print("Done, %d new rates." % len(rates))
 
 
-def _sound(which, mp3):
+def _sound(which, ogg):
     from shutil import copyfile
 
-    if not exists(mp3):
-        print('Specified sound file "%s" does not exist!' % mp3)
+    if not exists(ogg):
+        print('Specified sound file "%s" does not exist!' % ogg)
         return 128
-    if not mp3.endswith('.mp3'):
-        print('The sound file must be a MP3 and have ".mp3" as extension!')
+    if not ogg.endswith('.ogg'):
+        print('The sound file must be a OGG and have ".ogg" as extension!')
         return 128
 
     target = join(dirname(dirname(abspath(__file__))), 'static', 'sounds',
-                  which+'.mp3')
-    print('Copying "%s" to "%s"...' % (mp3, target))
-    copyfile(mp3, target)
+                  which+'.ogg')
+    print('Copying "%s" to "%s"...' % (ogg, target))
+    copyfile(ogg, target)
 
 
 def start_sound(args):
@@ -436,10 +436,10 @@ def main():
                       " i.e. only those with at least one played match. This"
                       " flag restores all tourneys.")
     subp.add_argument('config', help="Name of the configuration file")
-    subp.add_argument('url', default="http://sol.metapensiero.it/",
+    subp.add_argument('url', default="http://sol3.arstecnica.it/",
                       nargs="?",
                       help='URL from where historic data will be loaded'
-                      ' if different from "http://sol.metapensiero.it/".'
+                      ' if different from "http://sol3.arstecnica.it/".'
                       ' It may also be a file:// URI or a local file path'
                       ' name.')
     subp.set_defaults(func=restore_all)
@@ -498,17 +498,17 @@ def main():
 
     subp = subparsers.add_parser('start-sound',
                                  help=start_sound.__doc__)
-    subp.add_argument('sound', help="Name of the new MP3 sound file")
+    subp.add_argument('sound', help="Name of the new OGG sound file")
     subp.set_defaults(func=start_sound)
 
     subp = subparsers.add_parser('stop-sound',
                                  help=stop_sound.__doc__)
-    subp.add_argument('sound', help="Name of the new MP3 sound file")
+    subp.add_argument('sound', help="Name of the new OGG sound file")
     subp.set_defaults(func=stop_sound)
 
     subp = subparsers.add_parser('prealarm-sound',
                                  help=prealarm_sound.__doc__)
-    subp.add_argument('sound', help="Name of the new MP3 sound file")
+    subp.add_argument('sound', help="Name of the new OGG sound file")
     subp.set_defaults(func=prealarm_sound)
 
     args = parser.parse_args()
