@@ -15,7 +15,8 @@ Ext.define('SoL.module.Championships.Actions', {
     uses: [
         'Ext.Action',
         'MP.form.Panel',
-        'MP.window.Notification'
+        'MP.window.Notification',
+        'SoL.window.Help'
     ],
 
     statics: {
@@ -309,7 +310,8 @@ Ext.define('SoL.module.Championships', {
         'MP.grid.Panel'
     ],
     uses: [
-        'SoL.module.Championships.Actions'
+        'SoL.module.Championships.Actions',
+        'SoL.window.Help'
     ],
 
     id: 'championships-win',
