@@ -19,7 +19,8 @@ Ext.define('SoL.module.Clubs.Actions', {
         'Ext.Action',
         'Ext.form.field.File',
         'MP.form.Panel',
-        'MP.window.Notification'
+        'MP.window.Notification',
+        'SoL.window.Help'
     ],
 
     statics: {
@@ -401,7 +402,8 @@ Ext.define('SoL.module.Clubs', {
     ],
     uses: [
         'SoL.module.Clubs.Actions',
-        'SoL.form.field.FlagsCombo'
+        'SoL.form.field.FlagsCombo',
+        'SoL.window.Help'
     ],
 
     id: 'clubs-win',
