@@ -20,7 +20,8 @@ Ext.define('SoL.module.Players.Actions', {
         'Ext.form.field.File',
         'Ext.form.field.VTypes',
         'MP.form.Panel',
-        'MP.window.Notification'
+        'MP.window.Notification',
+        'SoL.window.Help'
     ],
 
     statics: {
@@ -69,7 +70,7 @@ Ext.define('SoL.module.Players.Actions', {
                     if(filterbar) {
                         filterbar.clearFilters();
                     }
-                    store.proxy.url = me.component.dataURL + '?dups=1';
+                    store.proxy.url = Ext.String.urlAppend(me.component.dataURL, 'dups=1');
                     store.load();
                     this.setText(_('Show all'));
                     this.dups = true;
@@ -388,7 +389,8 @@ Ext.define('SoL.module.Players', {
         'Ext.grid.plugin.DragDrop',
         'SoL.form.field.FlagsCombo',
         'SoL.module.Players.Actions',
-        'SoL.module.Players.MergePlugin'
+        'SoL.module.Players.MergePlugin',
+        'SoL.window.Help'
     ],
 
     statics: {
