@@ -16,7 +16,8 @@ Ext.define('SoL.module.Ratings.Actions', {
     uses: [
         'Ext.Action',
         'MP.form.Panel',
-        'MP.window.Notification'
+        'MP.window.Notification',
+        'SoL.window.Help'
     ],
 
     statics: {
@@ -347,7 +348,8 @@ Ext.define('SoL.module.Ratings', {
         'MP.grid.Panel'
     ],
     uses: [
-        'SoL.module.Ratings.Actions'
+        'SoL.module.Ratings.Actions',
+        'SoL.window.Help'
     ],
 
     id: 'ratings-win',
