@@ -17,7 +17,8 @@ Ext.define('SoL.module.Tourney', {
     ],
     uses: [
         'Ext.layout.container.Border',
-        'SoL.view.Tourney'
+        'SoL.view.Tourney',
+        'SoL.window.Help'
     ],
 
     id: 'tourney-win',
