@@ -416,7 +416,8 @@ Ext.define('SoL.module.Tourneys', {
         'MP.grid.Panel'
     ],
     uses: [
-        'SoL.module.Tourneys.Actions'
+        'SoL.module.Tourneys.Actions',
+        'SoL.window.Help'
     ],
 
     id: 'tourneys-win',
@@ -539,6 +540,9 @@ Ext.define('SoL.module.Tourneys', {
                         prized: false,
                         duration: 45,
                         prealarm: 5,
+                        phantomscore: 25,
+                        finals: 0,
+                        delaytoppairing: 1,
                         couplings: couplings || 'serial'
                     },
                     filters: [{
