@@ -263,6 +263,18 @@ Ext.define('SoL.view.Competitors.PlayersActions', {
             value: ids.join(','),
             operator: '<>'
         });
+
+        Ext.each(grid.plugins, function(p) {
+            if(p.ptype == 'filterbar') {
+                var field = p.fields.get('firstname');
+                if (field) {
+                    field.selectText();
+                    field.focus(false, 200);
+                }
+                return false;
+            }
+            return true;
+        });
     }
 });
 
@@ -611,18 +623,20 @@ Ext.define('SoL.view.Competitors.PlayerDrop', {
         var me = this;
         var present = false;
 
+        function is_present(comp, id) {
+            if(id == comp.get("idplayer1") ||
+               id == comp.get("idplayer2") ||
+               id == comp.get("idplayer3") ||
+               id == comp.get("idplayer4")) {
+                present = true;
+                return false;
+            } else
+                return null;
+        }
+
         for(var i=0; !present && i<sels.length; i++) {
             var id = sels[i].get("idplayer");
-            me.store.each(function(comp) {
-                if(id==comp.get("idplayer1") ||
-                   id==comp.get("idplayer2") ||
-                   id==comp.get("idplayer3") ||
-                   id==comp.get("idplayer4")) {
-                    present = true;
-                    return false;
-                } else
-                    return null;
-            });
+            me.store.each(function(comp) { return is_present(comp, id); });
         }
 
         return present;
