@@ -75,10 +75,8 @@ Ext.define('SoL.view.Matches.Actions', {
             iconCls: 'print-icon',
             disabled: tourney.readOnly,
             hidden: tourney.readOnly,
-            handler: function() {
-                var url = '/pdf/scorecards/' + tourney.idtourney;
-                window.location.assign(url);
-            }
+            scope: me.component,
+            handler: me.component.printCards
         }));
 
         me.printResultsAction = me.addAction(new Ext.Action({
@@ -143,6 +141,8 @@ Ext.define('SoL.view.Matches', {
         'SoL.view.Matches.Actions'
     ],
 
+    clicksToEdit: 1,
+
     statics: {
         ordinal: function(num) {
             var r;
@@ -325,6 +325,10 @@ Ext.define('SoL.view.Matches', {
                 xtype: 'matches-grid'
             };
 
+            function apply_filter(btn) {
+                me.matches_grid.filterOnTurn(btn.turn);
+            }
+
             for(var i=1; i <= config.tourney.currentturn; i++) {
                 cfg.lbar.push({
                     itemId: 'turn-' + i,
@@ -333,9 +337,7 @@ Ext.define('SoL.view.Matches', {
                     tooltip: Ext.String.format(
                         _('Show the matches {0} round.'), ordinalp(i)),
                     turn: i,
-                    handler: function(btn) {
-                        me.matches_grid.filterOnTurn(btn.turn);
-                    }
+                    handler: apply_filter
                 });
             }
 
@@ -387,13 +389,44 @@ Ext.define('SoL.view.Matches', {
 
         me.on("beforeedit", function(editor, event) {
             var tourney = me.module.tourney;
+            var ordinal = SoL.view.Matches.ordinal;
+            var ordinalp = SoL.view.Matches.ordinalp;
 
             if(tourney.prized)
                 return false;
 
             var rec = event.record;
             var phantom = rec.get("idcompetitor2") === null;
-            return (!phantom && rec.get("turn") == tourney.currentturn);
+
+            if(!me.allowEditPreviousTurns && rec.get("turn") < tourney.currentturn) {
+                Ext.Msg.confirm(
+                    _('Confirm edit of old round results'),
+                    Ext.String.format(
+                        _('Do you confirm you want to edit the results {0} round, even if the'
+                          + ' ranking is currently at {1}?<br/>Doing so the ranking will be'
+                          + ' updated but following rounds pairing will remain unchanged!'),
+                        ordinalp(rec.get("turn")),
+                        ordinal(tourney.currentturn)),
+                    function(response) {
+                        if(response == 'yes') {
+                            me.allowEditPreviousTurns = true;
+                            me.editingPlugin
+                                .startEdit(event.rowIdx, me.getColumnByName('score1'));
+                            Ext.create("MP.window.Notification", {
+                                position: 'tl',
+                                title: _('Changing old results'),
+                                html: Ext.String.format(
+                                    _('You are now allowed to change the results {0} round'),
+                                    ordinalp(rec.get("turn"))),
+                                iconCls: 'information-icon'
+                            }).show();
+                        }
+                    }
+                );
+            }
+
+            return (!phantom && (rec.get("turn") == tourney.currentturn
+                                 || me.allowEditPreviousTurns === true));
         });
 
         // Install a KeyMap on the grid that allows jumping to a given record
@@ -444,6 +477,8 @@ Ext.define('SoL.view.Matches', {
         var tourney = me.module.tourney;
         var lbar = me.child('toolbar[dock="left"]');
 
+        me.allowEditPreviousTurns = false;
+
         if(me.focusedCompetitor) {
             lbar.show();
             me.getColumnByName('turn').hide();
@@ -496,6 +531,8 @@ Ext.define('SoL.view.Matches', {
         var tourney = me.module.tourney;
         var lbar = me.child('toolbar[dock="left"]');
 
+        me.allowEditPreviousTurns = false;
+
         if(me.focusedCompetitor) {
             lbar.show();
             me.getColumnByName('turn').hide();
@@ -547,6 +584,8 @@ Ext.define('SoL.view.Matches', {
         var me = this;
         var tourney = me.module.tourney;
 
+        me.allowEditPreviousTurns = false;
+
         Ext.Ajax.request({
             url: '/tourney/deleteFromTurn',
             params: { idtourney: tourney.idtourney, fromturn: turn },
@@ -595,6 +634,8 @@ Ext.define('SoL.view.Matches', {
             return;
         }
 
+        me.allowEditPreviousTurns = false;
+
         store.filter({
             id: 'turn',
             property: 'turn',
@@ -618,6 +659,73 @@ Ext.define('SoL.view.Matches', {
         }
     },
 
+    printCards: function() {
+        var me = this;
+        var tourney = me.module.tourney;
+        var url = '/pdf/scorecards/' + tourney.idtourney;
+        var win;
+        var winWidth = 215;
+        var winHeight = 110;
+        var now = new Date();
+        var minValue = now;
+        var maxValue = Ext.Date.add(now, Ext.Date.HOUR, 2);
+
+        if(minValue.getDate() != maxValue.getDate()) {
+            // This happens after 10pm, when maxValue crosses midnight and thus its
+            // time value becomes smaller than the minValue time value: the timefield
+            // does not handle this, and there is no easy workaround other than
+            // showing all times...
+            minValue = maxValue = undefined;
+        }
+
+        var form = new Ext.form.Panel({
+            frame: true,
+            bodyPadding: '10 10 0',
+            defaults: {
+                labelWidth: 50,
+                anchor: '100%'
+            },
+            items: [{
+                xtype: 'timefield',
+                increment: 5,
+                allowBlank: false,
+                minValue: minValue,
+                maxValue: maxValue,
+                value: Ext.Date.add(now, Ext.Date.MINUTE, 10 + (5 - now.getMinutes() % 5))
+            }],
+            buttons: [{
+                text: _('Cancel'),
+                handler: function() {
+                    win.destroy();
+                }
+            }, {
+                text: _('Confirm'),
+                formBind: true,
+                handler: function() {
+                    var frm = form.getForm();
+                    if(frm.isValid()) {
+                        var starttime = frm.getFields().items[0].getValue().getTime();
+                        url += '?starttime=' + starttime;
+                        win.destroy();
+                        window.location.assign(url);
+                    }
+                }
+            }]
+        });
+
+        win = me.module.app.getDesktop().createWindow({
+            title: _('Estimated start'),
+            width: winWidth,
+            height: winHeight,
+            layout: 'fit',
+            minimizable: false,
+            maximizable: false,
+            items: [form]
+        });
+
+        win.show();
+    },
+
     commitChanges: function() {
         var me = this;
         var ok = true;
