@@ -157,6 +157,30 @@ class PlayerData(metaclass=Fixture):
         lastname = 'M'
         federation = ClubData.fic
 
+    class carlitob:
+        firstname = 'Carlito'
+        lastname = 'B'
+
+    class lorenzoh:
+        firstname = 'Lorenzo'
+        lastname = 'H'
+
+    class martinam:
+        firstname = 'Martina'
+        lastname = 'W'
+
+    class peterb:
+        firstname = 'Peter'
+        lastname = 'B'
+
+    class josefm:
+        firstname = 'Josef'
+        lastname = 'M'
+
+    class barbarat:
+        firstname = 'Barbara'
+        lastname = 'T'
+
 PlayerData.fata.owner = PlayerData.lele
 
 
@@ -540,6 +564,62 @@ class CompetitorData(metaclass=Fixture):
         tourney = TourneyData.odd
         player1 = PlayerData.bob
 
+    class ocomp4:
+        tourney = TourneyData.odd
+        player1 = PlayerData.pk
+
+    class ocomp5:
+        tourney = TourneyData.odd
+        player1 = PlayerData.blond
+
+    class ocomp6:
+        tourney = TourneyData.odd
+        player1 = PlayerData.juri
+
+    class ocomp7:
+        tourney = TourneyData.odd
+        player1 = PlayerData.fabiot
+
+    class ocomp8:
+        tourney = TourneyData.odd
+        player1 = PlayerData.lucab
+
+    class ocomp9:
+        tourney = TourneyData.odd
+        player1 = PlayerData.paolor
+
+    class ocomp10:
+        tourney = TourneyData.odd
+        player1 = PlayerData.danieled
+
+    class ocomp11:
+        tourney = TourneyData.odd
+        player1 = PlayerData.elisam
+
+    class ocomp12:
+        tourney = TourneyData.odd
+        player1 = PlayerData.carlitob
+
+    class ocomp13:
+        tourney = TourneyData.odd
+        player1 = PlayerData.lorenzoh
+
+    class ocomp14:
+        tourney = TourneyData.odd
+        player1 = PlayerData.martinam
+
+    class ocomp15:
+        tourney = TourneyData.odd
+        player1 = PlayerData.peterb
+
+    class ocomp16:
+        tourney = TourneyData.odd
+        player1 = PlayerData.josefm
+
+    class ocomp17:
+        tourney = TourneyData.odd
+        player1 = PlayerData.barbarat
+
     # Dazedodd tourney
 
     class docomp1:
