@@ -8,7 +8,7 @@
 from . import FunctionalTestCase
 
 
-class TestHtmlController(FunctionalTestCase):
+class TestLitViews(FunctionalTestCase):
 
     def test_index(self):
         self.app.get('/lit')
