@@ -441,6 +441,7 @@ class TestTourney(TestCase):
         self.assertEqual(len([m for m in t.matches if m.competitor2 is None]), 1)
         self.assertEqual([m for m in t.matches if m.competitor2 is None][0].score1,
                          t.phantomscore)
+        self.assertIs(t.matches[-1].competitor2, None)
         for m in t.matches:
             if m.turn==t.currentturn:
                 m.score1 = randint(1, 25)
@@ -450,8 +451,8 @@ class TestTourney(TestCase):
         self.assertEqual(len([m for m in t.matches if m.competitor2 is None]), 2)
         try:
             t.makeNextTurn()
-        except OperationAborted:
-            pass
+        except OperationAborted as e:
+            self.assertIn("without result", str(e))
         else:
             assert False, "Should have raised an error!"
 
@@ -467,6 +468,7 @@ class TestTourney(TestCase):
             self.assertEqual(len([m for m in t.matches if m.competitor2 is None]), turn)
             self.assertEqual([m for m in t.matches if m.competitor2 is None][0].score1,
                              t.phantomscore)
+            self.assertIs(t.matches[-1].competitor2, None)
             for m in t.matches:
                 if m.turn == t.currentturn and m.competitor2 is not None:
                     m.score1 = 10
@@ -695,6 +697,15 @@ class TestTourney(TestCase):
         s.flush()
         self.assertEqual(n.championship.description, 'SCR 2010 (test)')
 
+    def test_replay_double(self):
+        s = models.DBSession()
+        t = s.query(models.Tourney) \
+            .filter_by(description=TourneyData.double.description).one()
+        n = t.replay(TODAY+1*ONEDAY)
+        s.flush()
+        self.assertEqual(n.championship.description,
+                         ChampionshipData.double.description)
+
     def test_skip_worst_prize(self):
         s = models.DBSession()
 
@@ -736,6 +747,26 @@ class TestTourney(TestCase):
         self.assertEqual(len(skipped), 1)
 
 
+class TestTourneyBoardNumber(TestCase):
+    def test_phantom_match_last(self):
+        s = models.DBSession()
+        t = s.query(models.Tourney) \
+            .filter_by(description=TourneyData.odd.description).one()
+        ncompetitors = len(t.competitors)
+        self.assertEqual(ncompetitors % 2, 1)
+        self.assertEqual(t.matches, [])
+        for turn in range(1, ncompetitors-1):
+            t.makeNextTurn()
+            newmatches = [m for m in t.matches if m.turn == t.currentturn]
+            newmatches.sort(key=lambda m: m.board)
+            self.assertIs(newmatches[-1].competitor2, None)
+            self.assertEqual(newmatches[-1].board, (ncompetitors+1)/2)
+            for m in newmatches:
+                if m.competitor2 is not None:
+                    m.score1 = 10
+                    m.score2 = 0
+
+
 class TestTourneyFinals(TestCase):
     def test_no_finals(self):
         s = models.DBSession()
