@@ -39,6 +39,7 @@ def check_authorized_request(event,
                                                '/catalog',
                                                '/extjs-l10n',
                                                '/favicon.ico',
+                                               '/robots.txt',
                                                }):
     """Assert the request is authorized.
 
@@ -73,7 +74,8 @@ def check_authorized_request(event,
     if sw('/scripts') and request.registry.settings.get('desktop.debug', False):
         return
 
-    get_request_logger(request, logger).error('Unauthorized access to %s', request.path)
+    get_request_logger(request, logger).error('Unauthorized access to %s (%s)',
+                                              request.path, request.method)
 
     raise HTTPUnauthorized(_('You must re-authenticate yourself'))
 
