@@ -150,7 +150,7 @@ def mergePlayers(request):
     sas = DBSession()
     player = sas.query(Player).get(tid)
     try:
-        replaced = player.mergePlayers(sids, get_request_logger(request, logger))
+        replaced = player.mergePlayers(sids, get_request_logger(request, changes_logger))
     except OperationAborted as e:
         msg = str(e)
         get_request_logger(request, logger).error("Couldn't merge players: %s", msg)
