@@ -376,7 +376,7 @@ def championships(request, results):
     countdownstarted=False,
     finals=dict(hidden=True),
     finalturns=dict(hidden=True),
-    finalkind=dict(hidden=True),
+    finalkind=dict(hidden=True, nullable=True),
     Prizes=dict(hidden=True,
                 label=_championships_t.c.prizes.info['label'],
                 hint=_championships_t.c.prizes.info['hint']),
