@@ -120,6 +120,33 @@ def player(request):
     return get_data(request, Player)
 
 
+@view_config(route_name="lit_player_opponent", renderer="lit/player_opponent.mako")
+def opponent(request):
+    data = get_data(request, Player)
+
+    oguid = request.matchdict['opponent']
+    try:
+        opponent = data['session'].query(Player).filter_by(guid=oguid).one()
+    except NoResultFound:
+        t = translator(request)
+        e = t(_('No player with guid $guid'), mapping=dict(guid=oguid))
+        get_request_logger(request, logger).error("Couldn't create page: %s", e)
+        raise HTTPBadRequest(str(e))
+    except Exception as e: # pragma: no cover
+        get_request_logger(request, logger).critical("Couldn't create page: %s", e,
+                                                     exc_info=True)
+        raise HTTPInternalServerError(str(e))
+    else:
+        data['opponent'] = opponent
+        return data
+
+
+@view_config(route_name="lit_player_matches", renderer="lit/player_matches.mako")
+def matches(request):
+    return get_data(request, Player)
+
+
+
 @view_config(route_name="lit_players", renderer="lit/players.mako")
 def players(request):
     from itertools import groupby
